@@ -93,6 +93,9 @@ struct UserDataInner {
 
 #[tokio::main]
 async fn main() -> Result<(), String> {
+    #[cfg(not(windows))]
+    print!("\x1b]2;{}\x07", "ncspot");
+
     let backends = {
         let backends: Vec<&str> = audio_backend::BACKENDS.iter().map(|b| b.0).collect();
         format!("Audio backends: {}", backends.join(", "))
@@ -103,24 +106,24 @@ async fn main() -> Result<(), String> {
         .about("cross-platform ncurses Spotify client")
         .after_help(&*backends)
         .arg(
-            Arg::with_name("debug")
-                .short("d")
+            Arg::new("debug")
+                .short('d')
                 .long("debug")
                 .value_name("FILE")
                 .help("Enable debug logging to the specified file")
                 .takes_value(true),
         )
         .arg(
-            Arg::with_name("basepath")
-                .short("b")
+            Arg::new("basepath")
+                .short('b')
                 .long("basepath")
                 .value_name("PATH")
                 .help("custom basepath to config/cache files")
                 .takes_value(true),
         )
         .arg(
-            Arg::with_name("config")
-                .short("c")
+            Arg::new("config")
+                .short('c')
                 .long("config")
                 .value_name("FILE")
                 .help("Filename of config file in basepath")
@@ -292,17 +295,18 @@ async fn main() -> Result<(), String> {
                     data.cmd.handle(s, command);
                 }
             } else {
-                let parsed = command::parse(cmd_without_prefix);
-                if let Some(commands) = parsed {
-                    if let Some(data) = s.user_data::<UserData>().cloned() {
-                        for cmd in commands {
-                            data.cmd.handle(s, cmd);
+                match command::parse(cmd_without_prefix) {
+                    Ok(commands) => {
+                        if let Some(data) = s.user_data::<UserData>().cloned() {
+                            for cmd in commands {
+                                data.cmd.handle(s, cmd);
+                            }
                         }
                     }
-                } else {
-                    let mut main = s.find_name::<ui::layout::Layout>("main").unwrap();
-                    let err_msg = format!("Failed to parse command(s): \"{}\"", cmd_without_prefix);
-                    main.set_result(Err(err_msg));
+                    Err(err) => {
+                        let mut main = s.find_name::<ui::layout::Layout>("main").unwrap();
+                        main.set_result(Err(err.to_string()));
+                    }
                 }
             }
             ev.trigger();
